﻿using Microsoft.Win32;
using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

// http://data.deutschebahn.com/datasets/haltestellen/
// CC BY:   DB Station & Services AG

namespace WpfApplicationHaltestellen
{
    public partial class MainWindow : Window
    {
        Haltestelle[] haltestellen;

        public MainWindow()
        {
            InitializeComponent();
        }

        Haltestelle zuletztAngeklickteHaltestelle;

        void ellipseGeklickt(object sender, MouseEventArgs e)
        {
            Haltestelle soebenAngeklickteHaltestelle = (Haltestelle)((Ellipse)sender).Tag;
            //MessageBox.Show(((Haltestelle)((Ellipse)sender).Tag).Ort);
            if (zuletztAngeklickteHaltestelle != null)
            {
                 MessageBox.Show(GeoPunkt.BestimmeAbstand(zuletztAngeklickteHaltestelle.Position,
                     soebenAngeklickteHaltestelle.Position).ToString());
            }
            zuletztAngeklickteHaltestelle = soebenAngeklickteHaltestelle;
        }

        private void button_Click(object sender, RoutedEventArgs e)
        {
            OpenFileDialog ofd = new OpenFileDialog();
            if(ofd.ShowDialog() == true)
            {
                string dateiname = ofd.FileName;
                string[] zeilen = File.ReadAllLines(dateiname);
                haltestellen = new Haltestelle[zeilen.Length - 1]; // eins weniger, weil Spaltentitel als oberste Zeile
                for (int i = 1; i < zeilen.Length; i++)
                {
                    string[] teile = zeilen[i].Split(';');
                    double länge = double.Parse(teile[4], System.Globalization.CultureInfo.InvariantCulture);
                    double breite = double.Parse(teile[5], System.Globalization.CultureInfo.InvariantCulture);
                    haltestellen[i - 1] = new Haltestelle(teile[2], new GeoPunkt(länge, breite));
                }

                double minLänge = haltestellen.Min(x => x.Position.Lon);
                double maxLänge = haltestellen.Max(x => x.Position.Lon);
                double minBreite = haltestellen.Min(x => x.Position.Lat);
                double maxBreite = haltestellen.Max(x => x.Position.Lat);

                for (int d = 0; d < 2; d++) // erst die blauen, dann die roten
                {
                    for (int i = 0; i < haltestellen.Length; i++)
                    {
                        Haltestelle h = haltestellen[i];
                        if (d == 0 && !h.IstHbf || d == 1 && h.IstHbf)
                        {
                            Ellipse elli = new Ellipse();
                            elli.Width = 5.0;
                            elli.Height = 5.0;
                            elli.Fill = h.IstHbf ? Brushes.Red : Brushes.DarkBlue;
                            elli.ToolTip = h.Ort;
                            elli.Tag = h;
                            elli.MouseDown += ellipseGeklickt;
                            zeichenfläche.Children.Add(elli);
                            Canvas.SetLeft(elli, zeichenfläche.ActualWidth / (maxLänge - minLänge) * (h.Position.Lon - minLänge));
                            Canvas.SetBottom(elli, zeichenfläche.ActualHeight / (maxBreite - minBreite) * (h.Position.Lat - minBreite));
                        }
                    }
                }
            }
        }
    }

    class Haltestelle
    {
        string ort;
        GeoPunkt position;

        public Haltestelle(string ort, GeoPunkt position)
        {
            this.ort = ort;
            this.position = position;
        }

        public GeoPunkt Position
        {
            get { return position; }
        }

        public string Ort
        {
            get { return ort; }
        }

        public bool IstHbf
        {
            get { return ort.EndsWith("Hbf"); }
        }
    }
}
